@@ -1,3 +1,4 @@
+import sys
 import time
 import logging
 from collections import defaultdict
@@ -8,7 +9,6 @@ logger = logging.getLogger('pydispix')
 
 class RateLimitedEndpoint:
     def __init__(self, default_delay: int = 0):
-        self.rate_limited = True            # Not all endpoints are rate-limited
         self.requests_limit = None          # Total number of requests before reset time wait
         self.remaining_requests = 1          # Remaining number of requests before reset time wait
         self.reset_time = 0                 # How much time to wait once we hit reset
@@ -16,10 +16,6 @@ class RateLimitedEndpoint:
         self.default_delay = default_delay  # If no other limit is found, how long should we wait
 
     def update_from_headers(self, headers: CaseInsensitiveDict[str]):
-        if 'requests-remaining' not in headers:
-            self.rate_limited = False
-            return
-
         self.remaining_requests = int(headers.get('requests-remaining', 1))
         self.reset_time = int(headers.get('requests-reset', 0))
         self.cooldown_time = int(headers.get('cooldown-reset', 0))
@@ -27,8 +23,6 @@ class RateLimitedEndpoint:
             self.requests_limit = int(headers["requests-limit"])
 
     def get_wait_time(self):
-        if not self.rate_limited:
-            return self.default_delay
         if self.cooldown_time != 0:
             return self.cooldown_time
         if self.remaining_requests == 0:
@@ -36,15 +30,26 @@ class RateLimitedEndpoint:
 
         return self.default_delay
 
-    def sleep(seconds: int, show_progress: bool = False):
-        if show_progress:
-            raise NotImplementedError("show_progress is not yet implemented, it will be added in v0.4.0")
-        time.sleep(seconds)
+    def sleep(self, seconds: int, *, show_progress: bool = False):
+        # Progress bars shouldn't appear if we're waiting less than 5 seconds
+        # it tends to be spammy and doesn't really provide much value
+        if not show_progress or seconds < 5:
+            return time.sleep(seconds)
+
+        toolbar_width = 40
+
+        # Setup toolbar
+        sys.stdout.write(f"[{' ' * toolbar_width}]")
+        sys.stdout.flush()
+        sys.stdout.write("\b" * (toolbar_width + 1))  # return to start of line, after '['
+
+        for i in range(toolbar_width):
+            time.sleep(seconds / toolbar_width)
+            sys.stdout.write("#")
+            sys.stdout.flush()
+        sys.stdout.write("]\n")  # this ends the progress bar
 
     def wait(self, *, show_progress: bool = False):
-        if not self.rate_limited:
-            logger.debug("Sleeping default delay, not rate limited.")
-            return self.sleep(self.default_delay, show_progress=show_progress)
         if self.cooldown_time != 0:
             logger.warning(f"Sleeping {self.cooldown_time}s, on cooldown.")
             return self.sleep(self.cooldown_time, show_progress=show_progress)
@@ -52,7 +57,7 @@ class RateLimitedEndpoint:
             logger.warning(f"Sleeping {self.reset_time}s, on reset.")
             return self.sleep(self.reset_time, show_progress=show_progress)
 
-        logger.debug(f"Sleeping default delay, {self.remaining_requests} requests remaining.")
+        logger.debug(f"Sleeping default delay ({self.default_delay}), {self.remaining_requests} requests remaining.")
         return self.sleep(self.default_delay, show_progress=show_progress)
 
 
